package de.intevation.flys.client.server;

import javax.xml.xpath.XPathConstants;

import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.apache.log4j.Logger;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;

import de.intevation.artifacts.common.ArtifactNamespaceContext;
import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.artifacts.httpclient.exceptions.ConnectionException;
import de.intevation.artifacts.httpclient.http.HttpClient;
import de.intevation.artifacts.httpclient.http.HttpClientImpl;

import de.intevation.flys.client.client.services.UserService;
import de.intevation.flys.client.shared.exceptions.AuthenticationException;
import de.intevation.flys.client.shared.model.DefaultUser;
import de.intevation.flys.client.shared.model.User;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class UserServiceImpl
extends      RemoteServiceServlet
implements   UserService
{
    private static final Logger logger = Logger.getLogger(UserServiceImpl.class);


    public static final String ERROR_NO_SUCH_USER = "error_no_such_user";

    public User getCurrentUser(String serverUrl, String locale)
    throws AuthenticationException
    {
        HttpClient client = new HttpClientImpl(serverUrl);

        try {
            Document users = (Document) client.listUsers();

            String XPATH_USERS = "/art:users/art:user";

            NodeList theUsers = (NodeList) XMLUtils.xpath(
                users,
                XPATH_USERS,
                XPathConstants.NODESET,
                ArtifactNamespaceContext.INSTANCE);

            if (theUsers != null && theUsers.getLength() > 0) {
                Node user = theUsers.item(0);

                String uuid = XMLUtils.xpathString(
                    user, "@art:uuid", ArtifactNamespaceContext.INSTANCE);
                String name = XMLUtils.xpathString(
                    user, "@art:name", ArtifactNamespaceContext.INSTANCE);

                return new DefaultUser(uuid, name);
            }
        }
        catch (ConnectionException ce) {
            logger.error(ce, ce);
        }

        logger.error("No users existing in the server.");
        throw new AuthenticationException(ERROR_NO_SUCH_USER);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
